@@ -113,10 +113,6 @@ get_max_procs_count(void)
 	count += MaxConnections + autovacuum_max_workers + 1
 			+ max_worker_processes;
 
-#if PG_VERSION_NUM >= 140000 && defined(PGPRO_EE)
-	count += MaxATX;
-#endif
-
 	/*
 	 * Starting with pg12, wal senders aren't part of MaxConnections anymore
 	 * and have to be accounted for.
@@ -202,8 +198,7 @@ setup_gucs()
 				profile_pid_found = false,
 				profile_queries_found = false;
 
-	guc_vars = get_guc_variables();
-	numOpts = GetNumConfigOptions();
+	get_guc_variables_compat(&guc_vars, &numOpts);
 
 	for (i = 0; i < numOpts; i++)
 	{
@@ -456,7 +451,6 @@ pg_wait_sampling_get_current(PG_FUNCTION_ARGS)
 	{
 		MemoryContext		oldcontext;
 		TupleDesc			tupdesc;
-		WaitCurrentContext 	*params;
 
 		funcctx = SRF_FIRSTCALL_INIT();
 
@@ -550,7 +544,7 @@ pg_wait_sampling_get_current(PG_FUNCTION_ARGS)
 		else
 			nulls[2] = true;
 
-		values[3] = Int64GetDatumFast(item->queryId);
+		values[3] = UInt64GetDatum(item->queryId);
 		tuple = heap_form_tuple(funcctx->tuple_desc, values, nulls);
 
 		SRF_RETURN_NEXT(funcctx, HeapTupleGetDatum(tuple));
@@ -736,11 +730,11 @@ pg_wait_sampling_get_profile(PG_FUNCTION_ARGS)
 			nulls[2] = true;
 
 		if (pgws_collector_hdr->profileQueries)
-			values[3] = Int64GetDatumFast(item->queryId);
+			values[3] = UInt64GetDatum(item->queryId);
 		else
 			values[3] = (Datum) 0;
 
-		values[4] = Int64GetDatumFast(item->count);
+		values[4] = UInt64GetDatum(item->count);
 
 		tuple = heap_form_tuple(funcctx->tuple_desc, values, nulls);
 
@@ -852,7 +846,7 @@ pg_wait_sampling_get_history(PG_FUNCTION_ARGS)
 		else
 			nulls[3] = true;
 
-		values[4] = Int64GetDatumFast(item->queryId);
+		values[4] = UInt64GetDatum(item->queryId);
 		tuple = heap_form_tuple(funcctx->tuple_desc, values, nulls);
 
 		history->index++;
